==> qps_1.10.17.orig.tar.xz: qps-1.10.17/src/translations/qps_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="964"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pauzuj (Ctrl+Spacja)</translation>
    </message>
</context>
<context>
    <name>EventDialog</name>
    <message>
        <location filename="../watchdog.ui" line="23"/>
        <source>Watchdog 0.1 alpha</source>
        <translation type="unfinished">Watchdog 0.1 alpha</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="117"/>
        <source>Eventcat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="162"/>
        <source>Select condition</source>
        <translation>Wybierz warunek</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="170"/>
        <source>labelDescrition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="193"/>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="219"/>
        <source>process name</source>
        <translation>nazwa procesu</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="229"/>
        <source>cpu</source>
        <translation>procesor</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="248"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="280"/>
        <source>include already running process</source>
        <translation>uwzględnij już uruchomiony proces</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="309"/>
        <source>run command</source>
        <translation>wykonaj polecenie</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="342"/>
        <source>show Message</source>
        <translation>wyświetl wiadomość</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="367"/>
        <source>Help (Not yet. just concept)</source>
        <translation>Pomoc (nie zaimplementowano jeszcze)</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="394"/>
        <source>%p : pid
%c : command</source>
        <translation>%p : id procesu
%c : polecenie</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="425"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="432"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="439"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="446"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>ExecWindow</name>
    <message>
        <location filename="../message.ui" line="13"/>
        <source>Qps</source>
        <translation>Qps</translation>
    </message>
    <message>
        <location filename="../message.ui" line="27"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="335"/>
        <source>Detail</source>
        <translation>Szczegół</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="271"/>
        <source>/untitled.</source>
        <translation>/bez tytułu.</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="276"/>
        <source>Save As</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="277"/>
        <source>%1 Files (*.%2);;All Files (*)</source>
        <translation>%1 plików (*.%2);;Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="304"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="307"/>
        <source> s</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="312"/>
        <source>Screenshot Delay:</source>
        <translation>Opóźnienie zrzutu ekranu</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="314"/>
        <source>Hide This Window</source>
        <translation>Ukryj to okno</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="326"/>
        <source>New Screenshot</source>
        <translation>Nowy zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="327"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
</TS>

==> qps_1.10.18.orig.tar.xz: qps-1.10.18/src/translations/qps_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="986"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pauzuj (Ctrl+Spacja)</translation>
    </message>
</context>
<context>
    <name>EventDialog</name>
    <message>
        <location filename="../watchdog.ui" line="23"/>
        <source>Watchdog 0.1 alpha</source>
        <translation>Watchdog 0.1 alpha</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="117"/>
        <source>Eventcat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="162"/>
        <source>Select condition</source>
        <translation>Wybierz warunek</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="170"/>
        <source>labelDescrition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="193"/>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="219"/>
        <source>process name</source>
        <translation>nazwa procesu</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="229"/>
        <source>cpu</source>
        <translation>procesor</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="248"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="280"/>
        <source>include already running process</source>
        <translation>uwzględnij już uruchomiony proces</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="309"/>
        <source>run command</source>
        <translation>wykonaj polecenie</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="342"/>
        <source>show Message</source>
        <translation>wyświetl wiadomość</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="367"/>
        <source>Help (Not yet. just concept)</source>
        <translation>Pomoc (nie zaimplementowano jeszcze)</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="394"/>
        <source>%p : pid
%c : command</source>
        <translation>%p : id procesu
%c : polecenie</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="425"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="432"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="439"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="446"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>ExecWindow</name>
    <message>
        <location filename="../message.ui" line="13"/>
        <source>Qps</source>
        <translation>Qps</translation>
    </message>
    <message>
        <location filename="../message.ui" line="27"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="351"/>
        <source>Detail</source>
        <translation>Szczegół</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="294"/>
        <source>/untitled.</source>
        <translation>/bez tytułu.</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="299"/>
        <source>Save As</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="300"/>
        <source>%1 Files (*.%2);;All Files (*)</source>
        <translation>%1 plików (*.%2);;Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="327"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="330"/>
        <source> s</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="335"/>
        <source>Screenshot Delay:</source>
        <translation>Opóźnienie wykonania zrzutu ekranu:</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="337"/>
        <source>Hide This Window</source>
        <translation>Ukryj to okno</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="349"/>
        <source>New Screenshot</source>
        <translation>Nowy zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="350"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
</TS>
